@@ -1,7 +1,5 @@
 /******************************************************************************
- * mod_uploader / BasicFileWriter.h
- ******************************************************************************
- * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
+ * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
  * All rights reserved.
  *
@@ -24,56 +22,54 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BasicFileWriter.h 1003 2006-03-14 13:52:47Z svn $
+ * $Id: BasicFileWriter.h 2035 2006-11-23 16:14:21Z svn $
  *****************************************************************************/
 
 #ifndef BASIC_FILE_WRITER_H
 #define BASIC_FILE_WRITER_H
 
-#include "FileWriter.h"
-
-#include "apr_pools.h"
+#include "Environment.h"
 
 #include <cstdlib>
 
-#ifdef HAVE_CONFIG_H
-#include "mod_uploader_config.h"
-#endif
+#include "apr_mmap.h"
+
+#include "FileWriter.h"
 
 using namespace std;
 
 /**
- * @brief read  write Ȥäơեإǡ񤭽Ф饹
+ * @brief read と write を使って，ファイルへデータを書き出すクラス．
  */
 class BasicFileWriter: public FileWriter
 {
 public:
+    static const apr_int32_t OPEN_FLAG;
     /**
-     * 󥹥ȥ饯
+     * コンストラクタ．
      *
-     * offset ꤵƤϡΰְʹߤ˽񤭽ФԤޤ
+     * offset が指定されている場合は，その位置以降に書き出しを行います．
      *
-     * @param[in] pool ס
-     * @param[in] fd եϥɥ
-     * @param[in] offset 񤭽Ф򳫻Ϥ
+     * @param[in] pool プール
+     * @param[in] file ファイルハンドラ
+     * @param[in] offset 書き出しを開始する位置
      */
-    BasicFileWriter(apr_pool_t *pool, apr_file_t *fd, apr_size_t offset=0);
+
+public:
+    BasicFileWriter(apr_pool_t *pool, apr_file_t *file, apr_size_t offset=0);
     /**
-     * եؤν񤭽ФԤޤ
+     * ファイルへの書き出しを行います．
      *
-     * @param[in] buf 񤭽Фǡ
-     * @param[in] size 񤭽Ф
-     * @exception const char * 񤭽Ф˼Ԥ
+     * @param[in] buffer 書き出すデータ
+     * @param[in] size 書き出すサイズ
+     * @exception const char * 書き出しに失敗した場合
      */
-    void write(const void *buf, apr_size_t size);
-private:
-    BasicFileWriter(const BasicFileWriter&);
-    BasicFileWriter &operator=(const BasicFileWriter&);
+    void write_impl(const void *buffer, apr_size_t size);
 };
 
 #endif
 
 // Local Variables:
 // mode: c++
-// buffer-file-coding-system: euc-japan-dos
+// coding: utf-8-dos
 // End:
