@@ -1,7 +1,5 @@
 /******************************************************************************
- * mod_uploader / CGIResponseWriter.cpp
- ******************************************************************************
- * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
+ * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
  * All rights reserved.
  *
@@ -24,44 +22,69 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CGIResponseWriter.h 1003 2006-03-14 13:52:47Z svn $
+ * $Id: CGIResponseWriter.h 2085 2006-11-25 19:29:52Z svn $
  *****************************************************************************/
 
 #ifndef CGI_RESPONSE_WRITER_H
 #define CGI_RESPONSE_WRITER_H
 
+#include "Environment.h"
+
+#include <iostream>
+
+#include "apr_file_io.h"
+
 #include "ResponseWriter.h"
-
-#define APR_WANT_STDIO
-#include "apr_want.h"
-
-#ifdef HAVE_CONFIG_H
-#include "mod_uploader_config.h"
-#endif
+#include "CGIResponse.h"
 
 using namespace std;
 
 /**
- * @brief CGI ǥ쥹ݥ󥹤񤭽Ф饹
+ * @brief コンソールにでレスポンスを書き出すクラス．
  */
-class CGIResponseWriter : public ResponseWriter
+class CGIResponseWriter: public ResponseWriter
 {
 public:
-    CGIResponseWriter();
-    ~CGIResponseWriter();
-
-    void puts(const char *str)
+    CGIResponseWriter(CGIResponse::Handle *r=NULL)
     {
-        fputs(str, stdout);
-    };
 
-private:
-    static const apr_size_t BUFFER_SIZE = 32768;
+    };
+    void write(const char *str, apr_size_t length) const throw()
+    {
+        cout.write(str, static_cast<streamsize>(length));
+#ifdef DEBUG_TemplateExecutor
+        cout.flush();
+#endif
+    };
+    void write(const char *str) const throw()
+    {
+        cout << str;
+#ifdef DEBUG_TemplateExecutor
+        cout.flush();
+#endif
+    };
+    void write(int i) const throw()
+    {
+        cout << i;
+#ifdef DEBUG_TemplateExecutor
+        cout.flush();
+#endif
+    };
+    void finish() const throw()
+    {
+        cout.flush();
+    };
+    static int sendfile(CGIResponse::Handle *r,
+                        apr_file_t *file, apr_off_t length)
+    {
+        // TODO: 実装する
+        return OK;
+    };
 };
 
 #endif
 
 // Local Variables:
 // mode: c++
-// buffer-file-coding-system: euc-japan-dos
+// coding: utf-8-dos
 // End:
