@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemListReader.h 2056 2006-11-24 11:05:59Z svn $
+ * $Id: UploadItemListReader.h 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #ifndef UPOLOAD_ITEM_LIST_READER_H
@@ -41,6 +41,7 @@ using namespace std;
 
 class UploadItemList;
 class UploadItemReader;
+class ThumbnailList;
 
 /**
  * @brief アップロードアイテムのリストを読み出すクラス．
@@ -52,20 +53,25 @@ public:
      * アップロードアイテムを読み出します．
      *
      * @param[in] pool プール
-     * @param[in] dir_path アイテムが保存されているディレクトリ
+     * @param[in] data_dir_path アイテムが保存されているディレクトリ
+     * @param[in] thumb_dir_path サムネイルが保存されているディレクトリ
      * @param[in] shm 共有メモリ
+     * @param[in] thumbnail_list サムネイルのリスト
      * @param[in] max_list_size リストの最大サイズ
      * @return 掲示板のアップロードアイテム
      */
-    static UploadItemList *read(apr_pool_t *pool, const char *dir_path,
-                                apr_shm_t *shm, apr_size_t max_list_size);
+    static UploadItemList *read(apr_pool_t *pool, const char *data_dir_path,
+                                const char *thumb_dir_path, apr_shm_t *shm,
+                                ThumbnailList *thumbnail_list,
+                                apr_size_t max_list_size);
 
 private:
     UploadItemListReader();
 
     static void get_subdir_threads(apr_pool_t *pool, const char *sub_dir_path,
                                    UploadItemReader *uitem_reader,
-                                   UploadItemList *uitem_list);
+                                   UploadItemList *uitem_list,
+                                   ThumbnailList *thumbnail_list);
     static bool is_subdir_name_valid(const char *subdir_name);
     static bool is_file_name_valid(const char *file_name);
 };
