@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemReader.h 2066 2006-11-24 14:37:14Z svn $
+ * $Id: UploadItemReader.h 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_READER_H
@@ -82,7 +82,15 @@ public:
      * @retval true アイテムが存在する
      * @retval false アイテムが存在しない
      */
-    bool is_exist(apr_size_t item_id) const;
+    bool is_exist_item(apr_size_t item_id) const;
+    /**
+     * サムネイルが存在するかどうか調べます．
+     *
+     * @param[in] item_id アイテムの ID
+     * @retval true サムネイルが存在する
+     * @retval false サムネイルが存在しない
+     */
+    bool is_exist_thumbnail(apr_size_t item_id) const;
 
     static UploadItem *read(apr_pool_t *pool, const char *dir_path,
                            apr_size_t item_id);
