@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemWriter.h 2095 2006-11-26 07:59:41Z svn $
+ * $Id: UploadItemWriter.h 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_WRITER_H
@@ -56,8 +56,10 @@ public:
      *
      * @param[in] uitem アイテムデータ
      * @param[in] temp_file_path 一時ファイルへのパス
+     * @retval true サムネイルを作成した
+     * @retval false サムネイルを作成していない
      */
-    void write(UploadItem *uitem, const char *temp_file_path);
+    bool write(UploadItem *uitem, const char *temp_file_path);
     /**
      * アイテムヘッダを書き出します．
      *
@@ -77,7 +79,7 @@ private:
     void write_data(apr_pool_t *pool, UploadItem *uitem);
     void write_file(apr_pool_t *pool, UploadItem *uitem,
                     const char *temp_file_path);
-    void write_thumb(apr_pool_t *pool, UploadItem *uitem);
+    bool write_thumb(apr_pool_t *pool, UploadItem *uitem);
 
     void get_thumbnail_size(ImageFile *image_file,
                             apr_size_t *width, apr_size_t *height);
