@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_util.h 2095 2006-11-26 07:59:41Z svn $
+ * $Id: uploader_util.h 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_UTIL_H
@@ -54,7 +54,8 @@ const char FIREFOX_NAME_ENCODING[]                  = "utf-8";
 const char *get_word(apr_pool_t *pool, const char **input,
                      const char delimiter);
 
-void get_page(apr_pool_t *pool, const char *arg, apr_size_t *page_no);
+void get_page(apr_pool_t *pool, const char *arg, apr_size_t page_count,
+              apr_size_t *page_no);
 
 
 const char *get_dispos_encoding(const char *user_agent);
