@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 2080 2006-11-25 14:22:47Z svn $
+ * $Id: TemplateExecutor.cpp 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -39,7 +39,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2080 2006-11-25 14:22:47Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2144 2006-11-29 14:54:20Z svn $");
 #endif
 
 #ifdef DEBUG_TemplateExecutor
@@ -691,6 +691,7 @@ TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(int i) throw()
 #include "UploadItemListReader.h"
 #include "UploadItemIterator.h"
 #include "UploadItemVariableCreator.h"
+#include "ThumbnailList.h"
 #include "TemplateVariableCreator.h"
 #include "CGIResponseWriter.h"
 
@@ -736,7 +737,9 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     const char *tmpl_file_path;
     apr_size_t dump_level;
     apr_shm_t *item_list_shm;
+    apr_shm_t *thumbnail_list_shm;
     UploadItemList *item_list;
+    ThumbnailList *thumbnail_list;
 
     if (argc < 3) {
         THROW(MESSAGE_ARGUMENT_INVALID);
@@ -759,8 +762,13 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
 
     item_list_shm = create_shm(pool,
                                UploadItemList::get_memory_size(MAX_LIST_SIZE));
+    thumbnail_list_shm = create_shm(pool,
+                                    ThumbnailList::get_memory_size(MAX_LIST_SIZE));
+
+    thumbnail_list = ThumbnailList::get_instance(thumbnail_list_shm,
+                                                 MAX_LIST_SIZE);
     item_list = UploadItemListReader::read(pool, data_dir_path, item_list_shm,
-                                           MAX_LIST_SIZE);
+                                           thumbnail_list, MAX_LIST_SIZE);
 
     show_item("data dir", data_dir_path);
     show_item("template file", tmpl_file_path);
