@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 2095 2006-11-26 07:59:41Z svn $
+ * $Id: UploadItemList.cpp 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -38,10 +38,10 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2095 2006-11-26 07:59:41Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2144 2006-11-29 14:54:20Z svn $");
 
-#define AS_UHEADER_T(pointer) reinterpret_cast<UploadItem::header_t *>(pointer)
-#define AS_UITEM_LIST(pointer) reinterpret_cast<UploadItemList *>(pointer)
+#define AS_UHEADER(pointer)     reinterpret_cast<UploadItem::header_t *>(pointer)
+#define AS_UITEM_LIST(pointer)  reinterpret_cast<UploadItemList *>(pointer)
 
 /******************************************************************************
  * public メソッド
@@ -76,7 +76,7 @@ void UploadItemList::add(UploadItem *uitem)
         } else { // 末尾に追加
             load_header(uitem, header_list_ + *header_list_size_);
         }
-    } else {
+    } else { // 挿入
         memmove(header_list_ + i + 1, header_list_ + i,
                 sizeof(UploadItem::header_t) * (*header_list_size_ - i));
         load_header(uitem, header_list_ + i);
@@ -143,10 +143,10 @@ apr_size_t UploadItemList::get_memory_size(apr_size_t max_list_size)
 }
 
 void UploadItemList::dump_header_list(apr_pool_t *pool,
-                                      UploadItemList *item_list)
+                                      UploadItemList *list)
 {
-    for (apr_size_t i = 0; i < *(item_list->header_list_size_); i++) {
-        dump_header(pool, item_list->header_list_ + i);
+    for (apr_size_t i = 0; i < *(list->header_list_size_); i++) {
+        dump_header(pool, list->header_list_ + i);
     }
 }
 
@@ -161,7 +161,7 @@ void UploadItemList::child_init_impl()
 
 void UploadItemList::init_shm()
 {
-    header_list_ = AS_UHEADER_T(this + 1);
+    header_list_ = AS_UHEADER(this + 1);
     header_list_size_ = AS_SIZE(header_list_ + max_list_size_);
     total_file_size_ = AS_OFF(header_list_size_ + 1);
 
@@ -220,7 +220,7 @@ apr_off_t UploadItemList::calc_total_file_size() const
 void UploadItemList::load_header(UploadItem *uitem,
                                  UploadItem::header_t *header)
 {
-    *header = *(AS_UHEADER_T(uitem));
+    *header = *(AS_UHEADER(uitem));
 }
 
 void UploadItemList::dump_header(apr_pool_t *pool,
