@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.cpp 2101 2006-11-26 09:20:09Z svn $
+ * $Id: UploadItemManager.cpp 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -38,6 +38,7 @@
 #include "UploadItemManager.h"
 #include "UploadItem.h"
 #include "UploadItemList.h"
+#include "ThumbnailList.h"
 #include "TemporaryPool.h"
 #include "Locker.h"
 #include "ReadLocker.h"
@@ -46,7 +47,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2101 2006-11-26 09:20:09Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2144 2006-11-29 14:54:20Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -69,11 +70,13 @@ SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2101 2006-11-26 09:20:09Z svn $");
 /******************************************************************************
  * public メソッド
  *****************************************************************************/
-void UploadItemManager::init(UploadItemList *item_list)
+void UploadItemManager::init(UploadItemList *item_list,
+                             ThumbnailList *thumbnail_list)
 {
     clear_shm();
 
     item_list_ = item_list;
+    thumbnail_list_ = thumbnail_list;
 
     init_shm();
 }
@@ -106,11 +109,14 @@ void UploadItemManager::add(apr_pool_t *pool,
         old_uitem = AS_UITEM(item_list_->get_by_index(item_list_->size()-1));
 
         item_writer_.remove(pool, old_uitem);
+        thumbnail_list_->remove(old_uitem->get_id());
         item_list_->remove(old_uitem->get_id());
     }
 
     item_list_->add(uitem);
-    item_writer_.write(uitem, file_temp_path);
+    if (item_writer_.write(uitem, file_temp_path)) {
+        thumbnail_list_->add(uitem->get_id());
+    }
 
     *mtime_ = current_time;
 
@@ -126,6 +132,7 @@ void UploadItemManager::remove(apr_pool_t *pool, UploadItem *uitem)
     // 処理の順番を変えるとまずい
     item_writer_.remove(pool, uitem);
     item_list_->remove(uitem->get_id());
+    thumbnail_list_->remove(uitem->get_id());
 
     *mtime_ = apr_time_now();
 
@@ -159,15 +166,18 @@ UploadItem *UploadItemManager::get_item(apr_pool_t *pool, apr_size_t item_id)
 }
 
 apr_file_t *UploadItemManager::get_item_file(apr_pool_t *pool,
-                                             UploadItem *uitem)
+                                             apr_size_t item_id)
 {
     const char *file_path;
     apr_file_t *file;
+    UploadItem *uitem;
     // カウンタを保護するだけなので読み出しロックで OK
     ReadLocker manager_locker(manager_ref_count_);
 
     REQUIRE_MANAGER_LOCKED();
 
+    uitem = AS_UITEM(item_list_->get_by_id(item_id));
+
     file_path = UploadItemIO::get_file_path(pool, file_dir_path_, uitem);
 
     uitem->increment_download_count();
@@ -200,12 +210,13 @@ UploadItemManager *UploadItemManager::get_instance(apr_shm_t *shm,
 }
 
 UploadItemManager *UploadItemManager::child_init(apr_shm_t *shm,
-                                                 UploadItemList *item_list)
+                                                 UploadItemList *item_list,
+                                                 ThumbnailList *thumbnail_list)
 {
     UploadItemManager *item_manager;
 
     item_manager = AS_UITEM_MANAGER(apr_shm_baseaddr_get(shm));
-    item_manager->child_init_impl(item_list);
+    item_manager->child_init_impl(item_list, thumbnail_list);
 
     return item_manager;
 }
@@ -240,9 +251,11 @@ UploadItemManager::UploadItemManager(apr_pool_t *pool,
 
 }
 
-void UploadItemManager::child_init_impl(UploadItemList *item_list)
+void UploadItemManager::child_init_impl(UploadItemList *item_list,
+                                        ThumbnailList *thumbnail_list)
 {
     item_list_ = item_list;
+    thumbnail_list_ = thumbnail_list;
 
     attach_shm();
 }
