@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemWriter.cpp 2103 2006-11-26 11:38:53Z svn $
+ * $Id: UploadItemWriter.cpp 2141 2006-11-28 14:43:52Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -36,7 +36,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemWriter.cpp 2103 2006-11-26 11:38:53Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemWriter.cpp 2141 2006-11-28 14:43:52Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -49,10 +49,12 @@ UploadItemWriter::UploadItemWriter(apr_pool_t *pool, const char *data_dir_path,
 
 }
 
-void UploadItemWriter::write(UploadItem *uitem, const char *temp_file_path)
+bool UploadItemWriter::write(UploadItem *uitem, const char *temp_file_path)
 {
     TemporaryPool temp_pool(pool_);
+    bool is_thumbnail_created;
 
+    is_thumbnail_created = false;
     try {
         prepare_subdir(temp_pool.get(), uitem->get_id());
 
@@ -60,12 +62,14 @@ void UploadItemWriter::write(UploadItem *uitem, const char *temp_file_path)
         write_file(temp_pool.get(), uitem, temp_file_path);
 
         if (uitem->get_file_size() < VIW_THUMBNAIL_SIZE_LIMIT) {
-            write_thumb(temp_pool.get(), uitem);
+            is_thumbnail_created = write_thumb(temp_pool.get(), uitem);
         }
     } catch(const char *) {
         remove(temp_pool.get(), uitem);
         throw;
     }
+
+    return is_thumbnail_created;
 }
 
 void UploadItemWriter::write_data(apr_pool_t *pool,
@@ -114,7 +118,7 @@ void UploadItemWriter::write_file(apr_pool_t *pool, UploadItem *uitem,
     }
 }
 
-void UploadItemWriter::write_thumb(apr_pool_t *pool, UploadItem *uitem)
+bool UploadItemWriter::write_thumb(apr_pool_t *pool, UploadItem *uitem)
 {
     apr_size_t thumb_width;
     apr_size_t thumb_height;
@@ -126,8 +130,10 @@ void UploadItemWriter::write_thumb(apr_pool_t *pool, UploadItem *uitem)
 
         image.create_thumbnail(get_thumb_path(pool, uitem->get_id()),
                                thumb_width, thumb_height);
-    } catch(exception &) {
 
+        return true;
+    } catch(exception &) {
+        return false;
     }
 }
 
