@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 2124 2006-11-27 16:14:24Z svn $
+ * $Id: UploaderConfig.cpp 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -36,6 +36,7 @@
 #include "UploadItemList.h"
 #include "UploadItemManager.h"
 #include "UploadItemListReader.h"
+#include "ThumbnailList.h"
 #include "PostFlowController.h"
 #include "UploaderTemplate.h"
 #include "Macro.h"
@@ -43,7 +44,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2124 2006-11-27 16:14:24Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2144 2006-11-29 14:54:20Z svn $");
 
 #define PARAM_PREFIX "Uploader"
 
@@ -119,10 +120,12 @@ UploaderConfig::UploaderConfig(apr_pool_t *pool)
     per_page_item_number(0),
     is_debug_mode(false),
     pool_(pool),
-    list_shm_(NULL),
-    manager_shm_(NULL),
+    item_list_shm_(NULL),
+    thumbnail_list_shm_(NULL),
+    item_manager_shm_(NULL),
     flow_controller_shm_(NULL),
     item_list_(NULL),
+    thumbnail_list_(NULL),
     item_manager_(NULL)
 
 {
@@ -137,19 +140,25 @@ void UploaderConfig::init()
     check();
     load_template();
 
-    list_shm_ = create_shm
+    item_list_shm_ = create_shm
         (pool_, UploadItemList::get_memory_size(total_file_number_limit));
-    manager_shm_ = create_shm(pool_, UploadItemManager::get_memory_size());
+    thumbnail_list_shm_ = create_shm
+        (pool_, ThumbnailList::get_memory_size(total_file_number_limit));
+    item_manager_shm_ = create_shm(pool_, UploadItemManager::get_memory_size());
     flow_controller_shm_ = create_shm(pool_,
                                       PostFlowController::get_memory_size());
 
-    item_list_ = UploadItemListReader::read(pool_, data_dir_path, list_shm_,
+    thumbnail_list_ = ThumbnailList::get_instance(thumbnail_list_shm_,
+                                                  total_file_number_limit);
+    item_list_ = UploadItemListReader::read(pool_, data_dir_path,
+                                            thumb_dir_path, item_list_shm_,
+                                            thumbnail_list_,
                                             total_file_number_limit);
-    item_manager_ = UploadItemManager::get_instance(manager_shm_, pool_,
+    item_manager_ = UploadItemManager::get_instance(item_manager_shm_, pool_,
                                                     data_dir_path,
                                                     file_dir_path,
                                                     thumb_dir_path);
-    item_manager_->init(item_list_);
+    item_manager_->init(item_list_, thumbnail_list_);
 
     flow_controller_ = PostFlowController::get_instance(flow_controller_shm_,
                                                         PST_INTERVAL_SEC);
@@ -157,12 +166,15 @@ void UploaderConfig::init()
 
 void UploaderConfig::child_init()
 {
-    attach_shm(pool_, list_shm_);
-    attach_shm(pool_, manager_shm_);
+    attach_shm(pool_, item_list_shm_);
+    attach_shm(pool_, thumbnail_list_shm_);
+    attach_shm(pool_, item_manager_shm_);
     attach_shm(pool_, flow_controller_shm_);
 
-    item_list_ = UploadItemList::child_init(list_shm_);
-    item_manager_ = UploadItemManager::child_init(manager_shm_, item_list_);
+    item_list_ = UploadItemList::child_init(item_list_shm_);
+    thumbnail_list_ = ThumbnailList::child_init(thumbnail_list_shm_);
+    item_manager_ = UploadItemManager::child_init(item_manager_shm_,
+                                                  item_list_, thumbnail_list_);
 }
 
 void UploaderConfig::finalize()
@@ -170,8 +182,9 @@ void UploaderConfig::finalize()
     item_manager_->sync_all_item(pool_);
 
     apr_shm_destroy(flow_controller_shm_);
-    apr_shm_destroy(manager_shm_);
-    apr_shm_destroy(list_shm_);
+    apr_shm_destroy(item_manager_shm_);
+    apr_shm_destroy(thumbnail_list_shm_);
+    apr_shm_destroy(item_list_shm_);
 }
 
 void UploaderConfig::set_template(template_type_t type, const char *tmpl_file_path)
