@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2124 2006-11-27 16:14:24Z svn $
+ * $Id: uploader_handler.cpp 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -46,6 +46,8 @@
 #include "UploaderTemplate.h"
 #include "UploadItemVariableCreator.h"
 #include "UploadItemManager.h"
+#include "ThumbnailIterator.h"
+#include "ThumbnailVariableCreator.h"
 #include "CharCodeConverter.h"
 #include "Message.h"
 #include "Macro.h"
@@ -53,22 +55,28 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2124 2006-11-27 16:14:24Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2144 2006-11-29 14:54:20Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
     (strncmp(arg, command, LITERAL_STRLEN(command)) == 0)
 
+static const apr_size_t PER_PAGE_THUMBNAIL_NUMBER = 100;
+
 static const char BASE_URL_VAR_NAME[]           = "BASE_URL";
 static const char ITEM_VAR_NAME[]               = "ITEM";
 static const char ITEM_LIST_VAR_NAME[]          = "ITEM_LIST";
+static const char THUMBNAIL_LIST_VAR_NAME[]     = "THUMBNAIL_LIST";
 static const char MAX_FILE_SIZE[]               = "MAX_FILE_SIZE";
 static const char TOTAL_FILE_SIZE[]             = "TOTAL_FILE_SIZE";
 static const char TOTAL_FILE_NUMBER[]           = "TOTAL_FILE_NUMBER";
+static const char TOTAL_THUMBNAIL_NUMBER[]      = "TOTAL_THUMBNAIL_NUMBER";
 static const char PAGE_COUNT[]                  = "PAGE_COUNT";
 static const char CURRENT_PAGE[]                = "CURRENT_PAGE";
 
 static const char INDEX_COMMAND[]               = "index";
+static const char THUMBNAIL_COMMAND[]           = "thumbnail";
+static const char THUMBNAIL_VIEW_COMMAND[]      = "view";
 static const char UPLOAD_COMMAND[]              = "upload";
 static const char DOWNLOAD_COMMAND[]            = "download";
 static const char REMOVE_COMMAND[]              = "remove";
@@ -165,10 +173,10 @@ static int index(typename Response::Handle *r, UploaderConfig *config,
         return OK;
     }
 
-    get_page(r->pool, arg, &page_no);
     page_count = (config->get_item_list()->size() == 0)
         ? 1
         : (config->get_item_list()->size()-1)/config->per_page_item_number + 1;
+    get_page(r->pool, arg, page_count, &page_no);
 
     typename Response::Writer o(r);
     try {
@@ -215,6 +223,128 @@ static int index(typename Response::Handle *r, UploaderConfig *config,
     return OK;
 }
 
+template<class Response>
+static int thumbnail_view(typename Response::Handle *r, UploaderConfig *config,
+                          const char *arg)
+{
+    apr_size_t item_id;
+
+    item_id = static_cast<apr_size_t>
+        (apr_atoi64(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])));
+
+    try {
+        const char  *thumb_file_path;
+
+        Response::set_content_type(r, get_image_mime(THUMBNAIL_FILE_TYPE));
+#ifndef DEBUG
+        Response::set_modified_time(r,
+                                    config->get_item_manager()->get_mtime());
+        Response::set_last_modified(r,
+                                    config->get_item_manager()->get_mtime());
+
+        int status;
+        if ((status = Response::is_meets_condition(r)) != OK) {
+            return status;
+        }
+#endif
+        if (Response::is_head_method(r)) {
+            return OK;
+        }
+
+
+        thumb_file_path = UploadItemIO::get_thumb_path(r->pool,
+                                                       config->thumb_dir_path,
+                                                       item_id);
+
+        File thumb_file(r->pool, thumb_file_path);
+        thumb_file.open(APR_READ);
+
+        Response::Writer::sendfile(r, thumb_file.get_handle(),
+                                   thumb_file.get_size());
+    } catch(const char *message) {
+        return error<Response>(r, config, message);
+    }
+
+    return OK;
+}
+
+template<class Response>
+static int thumbnail(typename Response::Handle *r, UploaderConfig *config,
+                     const char *arg)
+{
+    const char *thumbnail_arg;
+    const char *thumbnail_command;
+    apr_size_t page_no;
+    apr_size_t page_count;
+
+    Response::set_content_type(r, "text/html");
+#ifndef DEBUG
+    Response::set_modified_time(r, config->get_item_manager()->get_mtime());
+    Response::set_last_modified(r, config->get_item_manager()->get_mtime());
+
+    int status;
+    if ((status = Response::is_meets_condition(r)) != OK) {
+        return status;
+    }
+#endif
+    if (Response::is_head_method(r)) {
+        return OK;
+    }
+
+    // コマンド
+    thumbnail_arg = arg;
+    thumbnail_command = get_word(r->pool, &thumbnail_arg, ARG_SEPARATE_STR[0]);
+
+    if (IS_REQUEST_COMMAND(thumbnail_command, THUMBNAIL_VIEW_COMMAND)) {
+        return thumbnail_view<Response>(r, config, thumbnail_arg);
+    }
+
+    page_count = (config->get_item_list()->size() == 0)
+        ? 1
+        : (config->get_thumbnail_list()->size()-1)/PER_PAGE_THUMBNAIL_NUMBER + 1;
+    get_page(r->pool, arg, page_count, &page_no);
+
+    typename Response::Writer o(r);
+    try {
+        UploaderTemplate *tmpl;
+        apr_size_t start_index;
+        apr_size_t end_index;
+
+        end_index = page_no * PER_PAGE_THUMBNAIL_NUMBER;
+        start_index = end_index - PER_PAGE_THUMBNAIL_NUMBER;
+
+        ThumbnailIterator thumbnail_iter(r->pool, config->get_thumbnail_list(),
+                                         start_index, end_index);
+
+        tmpl = config->get_template(UploaderConfig::THUMBNAIL_VIEW);
+
+        TemplateVariableCreator var_creator(r->pool, tmpl->get_ids());
+
+        var_creator.create(BASE_URL_VAR_NAME, config->base_url);
+
+        var_creator.create
+            (THUMBNAIL_LIST_VAR_NAME,
+             tmpl->get_thumbnail_var_creator()->create(r->pool,
+                                                       &thumbnail_iter));
+
+        var_creator.create(TOTAL_THUMBNAIL_NUMBER,
+                           config->get_thumbnail_list()->size());
+        var_creator.create(PAGE_COUNT, page_count);
+
+        var_creator.create(CURRENT_PAGE, page_no);
+
+        TemplateExecutor<typename Response::Writer> executor(r->pool, o);
+
+        executor.exec(tmpl->get_node_tree(), var_creator.get_variables(),
+                      tmpl->get_key_count());
+    } catch(const char *message) {
+        return error_with_log<Response>(r, o, config, message);
+    }
+    o.finish();
+
+    return OK;
+}
+
 template<class Response>
 static int upload(typename Response::Handle *r, UploaderConfig *config,
                   const char *arg)
@@ -388,7 +518,8 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
             return OK;
         }
 
-        item_file = config->get_item_manager()->get_item_file(r->pool, uitem);
+        item_file = config->get_item_manager()->get_item_file(r->pool,
+                                                              item_id);
 
         Response::set_accept_ranges(r);
 
@@ -544,10 +675,10 @@ static int admin(typename Response::Handle *r, UploaderConfig *config,
         return remove<Response>(r, config, admin_arg, true);
     }
 
-    get_page(r->pool, arg, &page_no);
     page_count = (config->get_item_list()->size() == 0)
         ? 1
         : (config->get_item_list()->size()-1)/config->per_page_item_number + 1;
+    get_page(r->pool, arg, page_count, &page_no);
 
     typename Response::Writer o(r);
     try {
@@ -644,6 +775,8 @@ int uploader_command_handler(typename Response::Handle *r, UploaderConfig *confi
 
     if ((*command == '\0') || IS_REQUEST_COMMAND(command, INDEX_COMMAND)) {
         return index<Response>(r, config, arg);
+    } else if (IS_REQUEST_COMMAND(command, THUMBNAIL_COMMAND)) {
+        return thumbnail<Response>(r, config, arg);
     } else if (IS_REQUEST_COMMAND(command, UPLOAD_COMMAND)) {
         return upload<Response>(r, config, arg);
     } else if (IS_REQUEST_COMMAND(command, DOWNLOAD_COMMAND)) {
